@@ -54,6 +54,26 @@ class NumberFormat(str, Enum):
     WON = "won"
     YEN = "yen"
     YUAN = "yuan"
+    HONG_KONG_DOLLAR = "hong_kong_dollar"
+    NEW_ZEALAND_DOLLAR = "new_zealand_dollar"
+    KRONA = "krona"
+    NORWEGIAN_KRONE = "norwegian_krone"
+    MEXICAN_PESO = "mexican_peso"
+    RAND = "rand"
+    NEW_TAIWAN_DOLLAR = "new_taiwan_dollar"
+    DANISH_KRONE = "danish_krone"
+    ZLOTY = "zloty"
+    BAHT = "baht"
+    FORINT = "forint"
+    KORUNA = "koruna"
+    SHEKEL = "shekel"
+    CHILEAN_PESO = "chilean_peso"
+    PHILIPPINE_PESO = "philippine_peso"
+    DIRHAM = "dirham"
+    COLOMBIAN_PESO = "colombian_peso"
+    RIYAL = "riyal"
+    RINGGIT = "ringgit"
+    LEU = "leu"
 
 
 class RollupFunction(str, Enum):
